@@ -442,7 +442,7 @@ def targList(mylist):
 
 #from autocorrect import Speller
 #from collections import defaultdict
-def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,neg_words =neg_words,adjDEL = adjDEL,only_opiAV = True,nncompound = False):
+def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,opi_verbs = opi_verbs ,neg_words =neg_words,adjDEL = adjDEL,nounDEL = nounDEL,only_opiAV = True,nncompound = False):
   non_opi_adjs = negADJ(neg_words,adjDEL)
   # 1. check spelling 
 
